@@ -14,7 +14,6 @@
 package main
 
 import (
-	"github.com/go-kit/log/level"
 	"github.com/prometheus/client_golang/prometheus"
 
 	"github.com/prometheus-community/ipmi_exporter/freeipmi"
@@ -62,17 +61,17 @@ func (c ChassisCollector) Args() []string {
 func (c ChassisCollector) Collect(result freeipmi.Result, ch chan<- prometheus.Metric, target ipmiTarget) (int, error) {
 	currentChassisPowerState, err := freeipmi.GetChassisPowerState(result)
 	if err != nil {
-		level.Error(logger).Log("msg", "Failed to collect chassis data", "target", targetName(target.host), "error", err)
+		logger.Error("Failed to collect chassis data", "target", targetName(target.host), "error", err)
 		return 0, err
 	}
 	currentChassisDriveFault, err := freeipmi.GetChassisDriveFault(result)
 	if err != nil {
-		level.Error(logger).Log("msg", "Failed to collect chassis data", "target", targetName(target.host), "error", err)
+		logger.Error("Failed to collect chassis data", "target", targetName(target.host), "error", err)
 		return 0, err
 	}
 	currentChassisCoolingFault, err := freeipmi.GetChassisCoolingFault(result)
 	if err != nil {
-		level.Error(logger).Log("msg", "Failed to collect chassis data", "target", targetName(target.host), "error", err)
+		logger.Error("Failed to collect chassis data", "target", targetName(target.host), "error", err)
 		return 0, err
 	}
 	ch <- prometheus.MustNewConstMetric(
