@@ -20,7 +20,6 @@ import (
 	"strings"
 	"sync"
 
-	"github.com/go-kit/log/level"
 	"github.com/prometheus/client_golang/prometheus"
 
 	"github.com/prometheus-community/ipmi_exporter/freeipmi"
@@ -34,10 +33,10 @@ type CollectorName string
 // ConfiguredCollector wraps an existing collector implementation,
 // potentially altering its default settings.
 type ConfiguredCollector struct {
-	collector    collector
-	command      string
-	default_args []string
-	custom_args  []string
+	collector   collector
+	command     string
+	defaultArgs []string
+	customArgs  []string
 }
 
 func (c ConfiguredCollector) Name() CollectorName {
@@ -53,13 +52,13 @@ func (c ConfiguredCollector) Cmd() string {
 
 func (c ConfiguredCollector) Args() []string {
 	args := []string{}
-	if c.custom_args != nil {
+	if c.customArgs != nil {
 		// custom args come first, this way it is quite easy to
 		// override a collector to use e.g. sudo
-		args = append(args, c.custom_args...)
+		args = append(args, c.customArgs...)
 	}
-	if c.default_args != nil {
-		args = append(args, c.default_args...)
+	if c.defaultArgs != nil {
+		args = append(args, c.defaultArgs...)
 	} else {
 		args = append(args, c.collector.Args()...)
 	}
@@ -74,20 +73,44 @@ func (c CollectorName) GetInstance() (collector, error) {
 	// This is where a new collector would have to be "registered"
 	switch c {
 	case IPMICollectorName:
+		if *nativeIPMI {
+			return IPMINativeCollector{}, nil
+		}
 		return IPMICollector{}, nil
 	case BMCCollectorName:
+		if *nativeIPMI {
+			return BMCNativeCollector{}, nil
+		}
 		return BMCCollector{}, nil
 	case BMCWatchdogCollectorName:
+		if *nativeIPMI {
+			return BMCWatchdogNativeCollector{}, nil
+		}
 		return BMCWatchdogCollector{}, nil
 	case SELCollectorName:
+		if *nativeIPMI {
+			return SELNativeCollector{}, nil
+		}
 		return SELCollector{}, nil
 	case SELEventsCollectorName:
+		if *nativeIPMI {
+			return SELEventsNativeCollector{}, nil
+		}
 		return SELEventsCollector{}, nil
 	case DCMICollectorName:
+		if *nativeIPMI {
+			return DCMINativeCollector{}, nil
+		}
 		return DCMICollector{}, nil
 	case ChassisCollectorName:
+		if *nativeIPMI {
+			return ChassisNativeCollector{}, nil
+		}
 		return ChassisCollector{}, nil
 	case SMLANModeCollectorName:
+		if *nativeIPMI {
+			return SMLANModeNativeCollector{}, nil
+		}
 		return SMLANModeCollector{}, nil
 	}
 	return nil, fmt.Errorf("invalid collector: %s", string(c))
@@ -186,42 +209,42 @@ func (s *IPMIConfig) UnmarshalYAML(unmarshal func(interface{}) error) error {
 	return nil
 }
 
-func (c IPMIConfig) GetCollectors() []collector {
+func (s *IPMIConfig) GetCollectors() []collector {
 	result := []collector{}
-	for _, co := range c.Collectors {
+	for _, co := range s.Collectors {
 		// At this point validity has already been checked
 		i, _ := co.GetInstance()
 		cc := ConfiguredCollector{
-			collector:    i,
-			command:      c.CollectorCmd[i.Name()],
-			default_args: c.CollectorArgs[i.Name()],
-			custom_args:  c.CustomArgs[i.Name()],
+			collector:   i,
+			command:     s.CollectorCmd[i.Name()],
+			defaultArgs: s.CollectorArgs[i.Name()],
+			customArgs:  s.CustomArgs[i.Name()],
 		}
 		result = append(result, cc)
 	}
 	return result
 }
 
-func (c IPMIConfig) GetFreeipmiConfig() string {
+func (s *IPMIConfig) GetFreeipmiConfig() string {
 	var b strings.Builder
-	if c.Driver != "" {
-		fmt.Fprintf(&b, "driver-type %s\n", c.Driver)
+	if s.Driver != "" {
+		fmt.Fprintf(&b, "driver-type %s\n", s.Driver)
 	}
-	if c.Privilege != "" {
-		fmt.Fprintf(&b, "privilege-level %s\n", c.Privilege)
+	if s.Privilege != "" {
+		fmt.Fprintf(&b, "privilege-level %s\n", s.Privilege)
 	}
-	if c.User != "" {
-		fmt.Fprintf(&b, "username %s\n", c.User)
+	if s.User != "" {
+		fmt.Fprintf(&b, "username %s\n", s.User)
 	}
-	if c.Password != "" {
-		fmt.Fprintf(&b, "password %s\n", freeipmi.EscapePassword(c.Password))
+	if s.Password != "" {
+		fmt.Fprintf(&b, "password %s\n", freeipmi.EscapePassword(s.Password))
 	}
-	if c.Timeout != 0 {
-		fmt.Fprintf(&b, "session-timeout %d\n", c.Timeout)
+	if s.Timeout != 0 {
+		fmt.Fprintf(&b, "session-timeout %d\n", s.Timeout)
 	}
-	if len(c.WorkaroundFlags) > 0 {
+	if len(s.WorkaroundFlags) > 0 {
 		fmt.Fprintf(&b, "workaround-flags")
-		for _, flag := range c.WorkaroundFlags {
+		for _, flag := range s.WorkaroundFlags {
 			fmt.Fprintf(&b, " %s", flag)
 		}
 		fmt.Fprintln(&b)
@@ -239,7 +262,7 @@ func (sc *SafeConfig) ReloadConfig(configFile string) error {
 	if configFile != "" {
 		config, err = os.ReadFile(configFile)
 		if err != nil {
-			level.Error(logger).Log("msg", "Error reading config file", "error", err)
+			logger.Error("Error reading config file", "error", err)
 			return err
 		}
 	} else {
@@ -255,7 +278,7 @@ func (sc *SafeConfig) ReloadConfig(configFile string) error {
 	sc.Unlock()
 
 	if configFile != "" {
-		level.Info(logger).Log("msg", "Loaded config file", "path", configFile)
+		logger.Info("Loaded config file", "path", configFile)
 	}
 	return nil
 }
@@ -281,7 +304,7 @@ func (sc *SafeConfig) ConfigForTarget(target, module string) IPMIConfig {
 	if module != "default" {
 		config, ok = sc.C.Modules[module]
 		if !ok {
-			level.Error(logger).Log("msg", "Requested module not found, using default", "module", module, "target", targetName(target))
+			logger.Error("Requested module not found, using default", "module", module, "target", targetName(target))
 		}
 	}
 
@@ -290,7 +313,7 @@ func (sc *SafeConfig) ConfigForTarget(target, module string) IPMIConfig {
 		config, ok = sc.C.Modules["default"]
 		if !ok {
 			// This is probably fine for running locally, so not making this a warning
-			level.Debug(logger).Log("msg", "Needed default config for, but none configured, using FreeIPMI defaults", "target", targetName(target))
+			logger.Debug("Needed default config for, but none configured, using FreeIPMI defaults", "target", targetName(target))
 			config = defaultConfig
 		}
 	}
